@@ -1,5 +1,5 @@
-from rediscluster.client import (
-    StrictRedis,
+from rediscluster.client import StrictRedis
+from redis.exceptions import (
     AuthenticationError,
     ConnectionError,
     DataError,
@@ -11,7 +11,7 @@ from rediscluster.client import (
 )
 from redis.client import parse_info
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 VERSION = tuple(map(int, __version__.split('.')))
 
 __all__ = [
